# Banish OEM self-signed certs forever and roll your own private LetsEncrypt
## Toss certbot or acme.sh onto some servers and baby, you got a stew going!
## Information:

+ Link: https://arstechnica.com/information-technology/2024/03/banish-oem-self-signed-certs-forever-and-roll-your-own-private-letsencrypt/
+ Source: Ars Technica
+ Author: Lee Hutchinson
+ Date published: 15 March 2024, 10:45
+ Date scraped: 15 March 2024, 11:02

## Article:
![Main article image](https://cdn.arstechnica.net/wp-content/uploads/2024/03/robot-judge-certified-760x380.jpg)



Previously, on "Weekend Projects for Homelab Admins With Control Issues," we created our own [dynamically updating DNS and DHCP setup](https://arstechnica.com/information-technology/2024/02/doing-dns-and-dhcp-for-your-lan-the-old-way-the-way-that-works/) with bind and dhcpd. We laughed. We cried. We hurled. Bonds were forged, never to be broken. And I hope we all took a little something special away from the journey—namely, a dynamically updating DNS and DHCP setup. Which we're now going to put to use!


If you're joining us fresh, without having gone through the previous part and wanting to follow this tutorial, howdy! There might be some parts that are more difficult to complete without a local instance of bind (or other authoritative resolver compatible with [nsupdate](https://en.wikipedia.org/wiki/Nsupdate)). We'll talk more about this when we get there, but just know that if you want to pause and go [do part one first](https://arstechnica.com/information-technology/2024/02/doing-dns-and-dhcp-for-your-lan-the-old-way-the-way-that-works/), you may have an easier time following along.

AdChoicesADVERTISING
The quick version: A LetsEncrypt of our own
-------------------------------------------


This article will walk through the process of installing [step-ca](https://github.com/smallstep/certificates), a standalone certificate authority-in-a-box. We'll then configure step-ca with an ACME provisioner—that's [Automatic Certificate Management Environment](https://en.wikipedia.org/wiki/Automatic_Certificate_Management_Environment), the technology that underpins LetsEncrypt and facilitates the automatic provisioning, renewal, and revocation of SSL/TLS certificates.


After we get step-ca listening for incoming ACME requests, we'll talk through the ways to get the self-hosted services on your LAN-speaking ACME so they can start automatically requesting certificates from our step-ca certificate authority—just like how LetsEncrypt works.


I'll focus exclusively on using [acme.sh](https://github.com/acmesh-official/acme.sh) for requesting and renewing certs on clients because it's the tool I'm most familiar with. But everything we do should be doable with any ACME client, so if you're more comfy with [certbot](https://github.com/certbot/certbot) or [dehydrated](https://github.com/bruncsak/ght-acme.sh) whatever, feel free to use that on your clients. The instructions should be pretty easy to adapt.


I didn’t understand any of that—we’re doing *what* now?
-------------------------------------------------------


So you know how you install a new self-hosted thing on your LAN, and when you log into its web interface, you get a "your connection isn't secure" warning because the thing you just installed is using a self-signed TLS certificate?


[![Warning blindness is a bad thing. This screen has important things to say.](https://cdn.arstechnica.net/wp-content/uploads/2024/03/self-signed-warning.jpg)](https://cdn.arstechnica.net/wp-content/uploads/2024/03/self-signed-warning.jpg) / Warning blindness is a bad thing. This screen has important things to say.Lee Hutchinson


Those warnings seem spurious, and most people quickly become blind to them, but they serve a very important purpose—even if it's a purpose a lot of people don't care about.


See, web browsers use TLS and HTTPS to try to accomplish two connected and equally important things: first, and most obviously, to encrypt the connection between you and the web resource you're accessing. But the second purpose—the one upended by self-signed certs and the source of the big warnings—is *identity verification.* An assurance that your encrypted communication is going to the person you think it's going to is almost as vital as having the communication encrypted in the first place.


A chain of trust extends from the various root [certificate authorities](https://en.wikipedia.org/wiki/Certificate_authority) down through the TLS certificates they issue to endpoints, and, at least in theory, one should be able to trust that a CA has done some amount of due diligence to verify the identity and ownership of the endpoints it issues certificates to. When you trust a certificate authority, you are trusting that the identity attestations on the certificates that CA issues are in fact accurate—that seeing a cert for "www.example.com" really does mean you're browsing "www.example.com" and not a site pretending to be that (or that your connection isn't being compromised via a [man-in-the-middle](https://en.wikipedia.org/wiki/Man-in-the-middle_attack) type attack).


Self-signed certificates break that chain of trust. Your browser has no way to validate that the resource is what its certificate says it is, because your browser doesn't trust the issuer.


This is why browsers show big scary warnings when you visit a page that presents a self-signed cert: You have encryption, but no identity verification. To banish the warnings, we have to have both—which is what we aim to provide with our step-ca installation. We're going to set up our own CA and get it trusted by your browser and by the devices and services for which it's going to be issuing certificates.




Why is this even necessary?
---------------------------


Honestly, it's not—you can continue to click through and ignore self-signed or otherwise invalid OEM certificates on your LAN and homelab because you're probably pretty sure of the provenance of the services behind those self-signed certs. But familiarity breeds contempt, and it's a *terrible* idea to get into the habit of dismissing TLS warning messages. They can warn you of legitimate danger if a site is compromised; thinking of them as something stupid to be routinely ignored is damaging and lessens the overall effectiveness of SSL/TLS.


And all things considered, this will be pretty easy, even if it sounds intimidating. (It will be easier than setting up bind and dhcpd!) For a long time, I churned out my own certificates using a rickety little ad-hoc CA I'd built with [this tutorial](https://jamielinux.com/docs/openssl-certificate-authority/) and manually copied them into place on all my LAN boxes. But the tools are there to make automation both super easy and super reliable, so we're going to use the tools.


What are we hosting this on?
----------------------------


If you built a project VM or container for part one, there's nothing preventing you from adding step-ca to it—the resource load is extremely light. Or, if you prefer some separation in your services, you can install step-ca on a new VM or container or pretty much anything you've got lying around, including a Raspberry Pi (there are [actively maintained ARM releases](https://github.com/smallstep/certificates/releases) of step-ca available if that's your jam).


I'm using a separate LXC container from the one I used for bind and dhcpd. Like with the previous container, I have it configured with 512MB of RAM and 8GB of disk space (though I could go with less of both if necessary), and it will be running Ubuntu 22.04 LTS.


As before, you certainly don't have to use Ubuntu—use the Linux distro of your choice. Or use BSD. Use whatever makes you happy! (Just don't use Windows. As with the last tutorial, I'm sure there's a way to get these same results on the Windows side of the house, but this is not a Windows tutorial, and I have no idea what those ways are.)


So regardless of how, get yourself to a bash prompt, make a note of your box's hostname and IP address, and let's jump in.


(A brief note: when I was figuring this stuff out, I leaned heavily on step-ca's [extensive and well-written tutorial documentation](https://smallstep.com/docs/tutorials/), and many of the procedures we'll use in this piece are lifted directly from there. Massive props to the folks at Smallstep for creating such a great repository of how-tos. If you have questions that I don't answer in this tutorial, definitely [check the docs](https://smallstep.com/docs/step-ca/index.html) because unlike many other projects, step-ca's are very, very good.)


Installing step-ca
------------------


Because there's no official repo to use, we'll be installing step-ca via dpkg. We'll need two installer files: one for step-ca itself and the other for the step-cli command line tools that we'll use to administer step-ca. Grab and run both with these commands:



```
$ wget https://dl.smallstep.com/cli/docs-ca-install/latest/step-cli_amd64.deb
$ wget https://dl.smallstep.com/certificates/docs-ca-install/latest/step-ca_amd64.deb
$ sudo dpkg -i step-cli_amd64.deb step-ca_amd64.deb
```
Select Code
(If you're not using Ubuntu, there are RPM and other packages available for other distros—[check the docs](https://smallstep.com/docs/step-ca/installation/#linux-packages-amd64) for details. But from here on out, I'll only be listing Ubuntu commands because I am lazy.)


Let's initialize step-ca so it writes some files and sets up shop. We don't have to use sudo for this command because we're not setting things up system-wide yet—that will come a few steps later.



```
$ step ca init
```
Select Code
This will kick off a script that will ask you a number of questions. First, we'll want to run our CA in *standalone* mode, so pick that. Next, to the question "What would you like to name your new PKI?", supply what you'd like your new CA to be called. Next give the hostname of the box on which we're installing step-ca, the port you want to bind to (I use :443, to bind to port 443 on all IPv4 interfaces), and the name you want to appear on your certificates as the "provisioner" (I'd recommend "webmaster@crazypants.lan," substituting in your LAN domain for "crazypants.lan"). Finally, the script will ask you for a password for your CA keys—let it auto-generate one and keep it handy, as we'll use it in just a moment.


[![Init'ing that certificate authority.](https://cdn.arstechnica.net/wp-content/uploads/2024/03/ca-init-output.jpg)](https://cdn.arstechnica.net/wp-content/uploads/2024/03/ca-init-output.jpg) / Init'ing that certificate authority.Lee Hutchinson


The script will chew on what you've given it, and after a couple of seconds, your certificate authority will be set up and operational. The script creates both a root certificate for your LAN CA and also an intermediate certificate—each has an important role to play in the public key infrastructure you've created.


(Briefly, the root CA is self-signed and establishes the root of trust for the CA, and one or more intermediate certificates are used to actually sign client certificate requests and issue certificates. In the event of compromise, it's much easier to replace an intermediate cert and not break the chain of trust with clients than it is to replace the root cert! But [don't take my word for it](https://www.youtube.com/watch?v=vAvQbEeTafk)—this is [a complicated topic](https://www.encryptionconsulting.com/root-vs-intermediate-certificates/), and it's worth [reading about in-depth](https://www.keyfactor.com/education-center/the-difference-in-root-certificates-vs-intermediate-certificates/).)


We also want to enable our new CA to understand and respond to ACME requests, so run the following command to make that happen:



```
$ step ca provisioner add acme --type ACME
```
Select Code
Before we move on, let's stash that CA password in a text file called `password.txt` in our current step-ca working directory under your home:



```
$ touch ~/.step/password.txt
```
Select Code
Edit that text file and paste the generated CA password into it. Once you're saved out of the file, adjust its permissions so that only the owning account can read it:



```
$ chmod 400 ~/.step/password.txt
```
Select Code


Trusting the new CA
-------------------


Now that step-ca has created its root and intermediate certificates, we want to add its root cert to the host's certificate trust store so that our host doesn't freak out when we start doing certificate authority stuff with our new certificate authority.


The *right* way to do this is to copy only the root certificate into the trust store and then make sure to include the intermediate certificate on clients so they have a complete chain of trust. But I'm lazy, and this is for a LAN-only CA. We're not curing cancer or going to space here. Human lives are not riding on your homelab. (Or, at least, they shouldn't be.) So I did the easy thing and copied both the root and the intermediate certificate into the root trust store. You can be a rule-follower and just copy the root certificate, or you can be lazy like me—your call:



```
$ sudo cp ~/.step/certs/root_ca.crt /usr/local/share/ca-certificates/
$ sudo cp ~/.step/certs/intermediate_ca.crt /usr/local/share/ca-certificates/
$ sudo update-ca-certificates
```
Select Code

If successful, you should see "2 added, 0 removed; done" in the output of the `update-ca-certificates` command.


Summoning daemons, part one: Preparing the ritual
-------------------------------------------------


We have a trusted CA, but it's not actually *doing* anything yet. We could manually poke at it with command line tools to make it issue certs, but what we really want to do is daemonize step-ca so it will run as a systemd service. The first thing that process requires is a user context under which to run the service, so let's create that user:



```
$ sudo useradd --system --home /etc/step-ca --shell /bin/false step
```
Select Code
It's also a good idea to use setcap to allow step-ca to listen for cert renewal requests on port 443 like a real server rather than a higher port:



```
$ sudo setcap CAP\_NET\_BIND\_SERVICE=+eip $(which step-ca)
```
Select Code
Now let's move the CA out from its default install location under your home directory and into a more accessible system-wide location under the `/etc` directory:



```
$ sudo mv ~/.step /etc/step-ca
```
Select Code
Then, while we're here, let's go ahead and fix the ownership on the `step-ca` directory so that it's owned by the step user we created a moment ago:



```
$ sudo chown -R step:step /etc/step-ca
```
Select Code
It's also time to modify the contents of our step-ca instance's configuration files to tell it that we've moved all of its stuff around. Pop open the smaller of the two step-ca config files for editing:



```
$ sudo vim /etc/step-ca/config/defaults.json
```
Select Code
We want to hunt down every instance of `/home/youraccount/.step/` and replace them all with `/etc/step-ca/` instead. My `defaults.json` file needed two such replacements, on line 3 (the `ca-config` line) and line 5 (the `root` line).


If you're doing this in vi or vim, you can accomplish the necessary searching and replacing with the magic of the substitution command:



```
:%s/home\/youraccount\/\.step/etc\/step-ca/g
```
Select Code
Your `defaults.json` file ought to look something like this when done:



```
{
"ca-url": "https://certifier.crazypants.lan",
"ca-config": "/etc/step-ca/config/ca.json",
"fingerprint": "big "ol' string",
"root": "/etc/step-ca/certs/root\_ca.crt"
}
```
Select Code
...except instead of "big ol' string," it'll have a big ol' string of letters and numbers in there.


Next, we repeat the same substitution procedure on the other config file:



```
$ sudo vim /etc/step-ca/config/ca.json
```
Select Code
My copy of `ca.json` needed four substitutions, on what, for me, were lines 2, 4, 5, and 16. I won't paste `ca.json` file in here because it's considerably longer than `defaults.json`, but if you found four substitutions, then you're probably good.


Before we move on from `ca.json`, let's make one more set of changes. By default, step-ca's TLS certificates are valid for 24 hours, and I find that inconveniently short. Let's change the expiration to seven days, which gives us a bit more breathing room so our certs won't all expire if we ever have to take the CA offline for more than a day.


To change the default expiration length, look for the `claims` section and add the following three lines:



```
"claims:" {
"defaultTLSCertDuration": "168h",
"minTLSCertDuration": "24h,
"maxTLSCertDuration": "168h",
```
Select Code
(Note that because this is a JSON file, you might want to paste it into [a JSON validator like this one](https://jsonlint.com/) before saving it because JSON is picky, and adding lines without being mindful of its particular syntax preferences can cause errors.)


With those changes made, save and close `ca.json`.





## Tags:
***email-adresses***: webmaster@crazypants.lan
***urls***: https://dl.smallstep.com/certificates/docs-ca-install/latest/step-ca_amd64.deb https://dl.smallstep.com/cli/docs-ca-install/latest/step-cli_amd64.deb http://s/home\/youraccount\/.step/etc\/step-ca/gSelect https://certifier.crazypants.lan

### Autogenerated tags:
[[step-ca]] [[sudo]] [[self-signed]] [[certs]] [[tls]] [[ca.json]] [[homelab]] [[letsencrypt]] [[ubuntu]] [[windows]]
