# Doing DNS and DHCP for your LAN the old way—the way that works
## Are you a sysadmin with control issues who needs a weekend project? Look no further!
## Information:

+ Link: https://arstechnica.com/information-technology/2024/02/doing-dns-and-dhcp-for-your-lan-the-old-way-the-way-that-works/
+ Source: Ars Technica
+ Author: Lee Hutchinson
+ Date published: 16 February 2024, 11:30
+ Date scraped: 16 February 2024, 12:02

## Article:
![Main article image](https://cdn.arstechnica.net/wp-content/uploads/2024/02/lee-dns-robot-stomp-760x380.jpg)



Here's a short summary of the next 7,000-ish words for folks who hate the thing recipe sites do where the authors babble about their personal lives for pages and pages before getting to the cooking: This article is about how to install [bind](https://en.wikipedia.org/wiki/BIND) and [dhcpd](https://en.wikipedia.org/wiki/DHCPD) and tie them together into a functional dynamic DNS setup for your LAN so that DHCP clients self-register with DNS, and you always have working forward and reverse DNS lookups. This article is intended to be part one of a two-part series, and in part two, we'll combine our bind DNS instance with an ACME-enabled LAN certificate authority and set up LetsEncrypt-style auto-renewing certificates for LAN services.


If that sounds like a fun couple of weekend projects, you're in the right place! If you want to fast-forward to where we start installing stuff, skip down a couple of subheds to the tutorial-y bits. Now, excuse me while I babble about my personal life.


My name is Lee, and I have a problem
------------------------------------


(Hi, Lee.)


I am a tinkering homelab sysadmin forever chasing the enterprise dragon. My understanding of what "normal" means, in terms of the things I should be able to do in any minimally functioning networking environment, was formed in the days just before and just after 9/11, when I was a fledgling admin fresh out of college, working at an enormous company that made planes starting with the number "7." I tutored at the knees of a whole bunch of different mentor sysadmins, who ranged on the graybeard scale from "fairly normal, just writes his own custom GURPS campaigns" to "lives in a Unabomber cabin in the woods and will only communicate via GPG." If there was one consistent refrain throughout my formative years marinating in that enterprise IT soup, it was that *forward and reverse DNS should always work.* Why? Because just like a clean bathroom is generally a sign of a nice restaurant, having good, functional DNS (forward *and* reverse) is a sign that your IT team knows what it's doing.


Forward and reverse lookups?
----------------------------

In the fancypants jargon of DNS, a "forward lookup" is a DNS query that presents the DNS server with a hostname and asks the DNS server to look up and return the corresponding IP address.
Much like a reverse phonebook (old people will understand what that means), a "reverse lookup" is a DNS query that gives the server an IP address and asks for the corresponding hostname.


These lookups come from different DNS zones, and having one type of query working successfully does not mean the other will work. We'll make sure to get both working for this tutorial.


Just look at what the masses have to contend with outside of the datacenter, where madness reigns. Look at the state of the average user's LAN—is there even a search domain configured? Do reverse queries on dynamic hosts work? Do *forward* queries on dynamic hosts even work? How can anyone live like this?!


I decided long ago that *I* didn't have to, so I've maintained a linked bind and dhcpd setup on my LAN for more than ten years. Also, I have control issues, and I like my home LAN to function like the well-run enterprise LANs I used to spend my days administering. It's kind of like how car people think: If you're not driving a stick shift, you're not really driving. I have the same kind of dumb hang-up, but for network services.


Honestly, though, running your LAN with bind and dhcpd isn't even that much work—those two applications underpin a huge part of the modern Internet. The packaged versions that come with most modern Linux distros are ready to go out of the box. They certainly beat the pants off of the minimal DNS/DHCP services offered by most SOHO NAT routers. Once you have bind and dhcpd configured, they're bulletproof. The only time I interact with my setup is if I need to add a new static DHCP mapping for a host I want to always grab the same IP address.


So, hey, if the idea of having perfect forward and reverse DNS lookups on your LAN sounds exciting—and, come on, who *doesn't* want that?!—then pull up your terminal and strap in because we're going make it happen.


(Note that I'm relying a bit on Past Lee and [this old blog entry](https://blog.bigdinosaur.org/running-bind9-and-isc-dhcp/) for some of the explanations in this piece, so if any of the three people who read my blog notice any similarities in some of the text, it's because Past Lee wrote it first and I am absolutely stealing from him.)


But wait, there’s more!
-----------------------


This piece is intended to be part one of two. If the idea of having one's own bind and dhcpd servers sounds a little silly (and it's not—it's *awesome*), it's actually a prerequisite for an additional future project with serious practical implications: our own fully functioning local ACME-enabled certificate authority capable of answering DNS-01 challenges so we can issue our own certificates to LAN services and not have to deal with TLS warnings like plebes.


("But Lee," you say, "why not just use actual-for-real LetsEncrypt with a real domain on my LAN?" Because that's considerably more complicated to implement if one does it the right way, and it means potentially dealing with [split-horizon DNS](https://en.wikipedia.org/wiki/Split-horizon_DNS) and [hairpinning](https://en.wikipedia.org/wiki/Network_address_translation#NAT_loopback) if you also need to use that domain for any Internet-accessible stuff. Split-horizon DNS is handy and useful if you have requirements that demand it, but if you're a home user, you probably don't. We'll keep this as simple as possible and use LAN-specific DNS zones rather than real public domain names.)


We'll tackle all the certificate stuff in part two—because we have a ways to go before we can get there.




What are we hosting this DNS business on?
-----------------------------------------


Since we'll be installing things, we need something on which to install those things. The good news is that bind and dhcpd are extremely lightweight and don't need a lot of resources to function, so you can run them on pretty much anything.


My choice for exercises like this is an LXC container, which you can spin up on any modern Linux distro (and which works particularly well on Ubuntu Server via [LXD](https://ubuntu.com/server/docs/containers-lxd)). If you're more old-school and all that containerization talk sounds like gibberish, you might consider a Linux virtual machine to install stuff on. Or keep it physical and try this on a Raspberry Pi or other tiny computer—bind and dhcpd would be happy to run on something like that, and although I haven't looked, I'm betting there are ARM versions of each available in the repos.


For the screenshots and instructions in this piece, I'll be using Ubuntu 22.04 LTS—because that's the latest LTS release available as I type this. Presumably, everything will also be fine with 24.04 LTS if you're reading this *in the future.*


Don't feel like you need to stick with Ubuntu Server for this tutorial just because I'm using it. Use Debian. Use Fedora. Use AlmaLinux. Hell, use Arch if you hate yourself. There are no judgments here. Remember the maxim of the [Scary Devil Monastery](http://www.catb.org/jargon/html/S/scary-devil-monastery.html): *All software sucks, all hardware sucks.* Pick the thing you're most comfortable with, get yourself to a bash prompt, and let's jump in.


But wait! I want to do this with Windows!
-----------------------------------------


Sorry, I've got nothing.


Is there a way to get great DNS and DHCP going in a Windows server environment? Absolutely. And if learning about that is your jam, the Googles are [right here](https://www.google.com/search?q=how+do+i+maek+windows+dns+serbar). Otherwise, for this tutorial, hop aboard the Linux train! It's fine and not scary at all. You don't have to compile your own kernel or anything like that—we'll mostly just be editing text config files. Spin up a Hyper-V instance of Ubuntu LTS and follow along! You won't get Linux Cooties or anything. I mean, you *probably* won't.


Install the things! (If you were skipping ahead, stop here)
-----------------------------------------------------------


All righty, let's get logged into the box where we'll do all of this stuff!


Assuming you're starting out on a fresh Ubuntu 22.04 LTS install, you'll want to create a non-root user to log in as and then bless that user with the unlimited power of root using [`visudo`](https://www.unixtutorial.org/how-to-use-visudo/). You'll also want to run an `apt update` and `apt upgrade` (or your distro's equivalent, but from here on out, instructions are Ubuntu-only because I'm lazy) to make sure we're all up to date before starting.


Make note of the hostname and IP address of the server you're using! I'd recommend setting it up with a static IP address, and I'd recommend setting the hostname to be `dnsbox`. (You can name it whatever you want, but this guide is going to assume your server is named `dnsbox`, so whenever you see `dnsbox`, replace it with your server's hostname.) I'll be using the IP address 192.168.1.55 for `dnsbox` throughout this piece, so make sure to substitute in your own `dnsbox`'s IP address whenever you see 192.168.1.55.


With that out of the way, let's start installing:



```
$ sudo apt install bind9 isc-dhcp-server
```
Select Code
[![Installing away!](https://cdn.arstechnica.net/wp-content/uploads/2024/02/bind-01.jpg)](https://cdn.arstechnica.net/wp-content/uploads/2024/02/bind-01.jpg) / Installing away!Lee Hutchinson


DNS should be running immediately, but the DHCP server in its default Ubuntu configuration isn't set up to listen on any IPv4 interfaces and won't actually start. And that's fine, because we don't want it to listen until we have it configured anyway. (I'll confusingly refer to the DHCP server as `dhcpd` throughout, even though the package it comes from is called `isc-dhcp-server`.)




Get DNS operational
-------------------


Let's focus first on bind, or `named` (that's pronounced "name dee," as in "the name daemon," not "named" as in past tense). Being a good \*nix citizen, bind keeps its configuration files in `/etc/bind`:


[![The contents of /etc/bind just after install.](https://cdn.arstechnica.net/wp-content/uploads/2024/02/bind-02.jpg)](https://cdn.arstechnica.net/wp-content/uploads/2024/02/bind-02.jpg) / The contents of /etc/bind just after install.Lee Hutchinson


There are three files we're particularly interested in: `named.conf`, `named.conf.options`, and `named.conf.local`. The first file links the whole config together; the `.options` file is where you should set bind's configuration options; and the `.local` file is where we'll specify the zone(s) for which our bind instance will serve queries.


First, pop open `named.conf` in your favorite editor. The prepackaged version of the file included with the Ubuntu 22.04 LTS distro doesn't have much in it:


[![The named.conf file. Kinda empty in here.](https://cdn.arstechnica.net/wp-content/uploads/2024/02/bind-03.jpg)](https://cdn.arstechnica.net/wp-content/uploads/2024/02/bind-03.jpg) / The named.conf file. Kinda empty in here.Lee Hutchinson


We'll begin our additions here. First, we'll define an access control list named `internal-net` that points at our internal network. This ACL will be our shorthand by which we can refer to trusted addresses we want to be able to use our bind server. Make this addition above the `include` statements so that the ACL has already been instantiated when the other config files are parsed for inclusion (since those files will eventually reference this ACL once we get to editing them):



```
acl internal-net {
    localhost;
    192.168.1/24;
};
```
Select Code
This assumes you're using 192.168.1.0/24 as your LAN segment. I use 10.10.10.0/24 for my trusted LAN segment, and I have a couple of other 10.10.x.0/24 segments for other purposes that I also want to be able to query DNS, so my `internal-net` ACL looks like this, instead:



```
acl internal-net {
    localhost;
    10.10/16;
};
```
Select Code
You'll want to tune your ACL as appropriate so that it points to the right network segment or segments.


Once you have your ACL in, add one more section below that to make sure the server ignores queries coming in over IPv6:



```
server ::/0 {
    bogus yes;
};
```
Select Code
This will make sure that bind knows that traffic coming in over any IPv6 interface should be ignored. (If you want to set this up with IPv6, go right ahead! Unfortunately, Frontier currently doesn't do IPv6 in my neck of the woods. Because I don't have IPv6 configured locally and also want to keep this guide from ballooning even bigger than it already is, I'm going IPv4-only.)


With those changes in, save `named.conf`. Sans comments, it should now look something like this, with your IP address range specified in the ACL:



```
acl internal-net {
	localhost;
    192.168.1/24;
};

server ::/0 {
	bogus yes;
};

include "/etc/bind/named.conf.options";
include "/etc/bind/named.conf.local";
include "/etc/bind/named.conf.default-zones";
```
Select Code
Now let's start configuring things in `named.conf.options`. Again, the packaged version of the file that comes with Ubuntu 22.04 LTS is pretty minimal:


[![Starting out with named.conf.options.](https://cdn.arstechnica.net/wp-content/uploads/2024/02/bind-04.jpg)](https://cdn.arstechnica.net/wp-content/uploads/2024/02/bind-04.jpg) / Starting out with named.conf.options.Lee Hutchinson


We'll leave `directory "/var/cache/bind";` alone, but let's comment out the other two lines. First, strike `dnssec-validation auto`—it's unnecessary since we won't be messing with [DNSSEC](https://en.wikipedia.org/wiki/Domain_Name_System_Security_Extensions). Then strike `listen-on-v6 { any; }`, which is unnecessary because we're sticking with IPv4 only.


Now add the following four lines below the big block of comments but before the final closing `}` brace:



```
allow-query { internal-net; };
allow-query-cache { internal-net; };
allow-recursion { none; };
allow-transfer { none; };
```
Select Code
Here's the breakdown on those four lines:


* `allow-query { internal-net; };` tells bind to only allow DNS queries from the internal-net ACL we previously set.
* `allow-query-cache { internal-net; };` tells bind to only return cached query results to queries coming from the internel-net ACL.
* `allow-recursion { none; };` tells bind to not do [recursive lookups](https://www.cloudflare.com/learning/dns/what-is-recursive-dns/) for anyone—in other words, this server should only be returning results for hosts over which it is [authoritative](https://umbrella.cisco.com/blog/what-is-the-difference-between-authoritative-and-recursive-dns-nameservers). This is not intended to be a forwarding or fully recursive resolver (it could be either if you want it to, but that's beyond the scope of this guide).
* `allow-transfer { none; };` tells bind not not allow any other DNS server to request a [zone transfer](https://en.wikipedia.org/wiki/DNS_zone_transfer). If you want to have multiple redundant DNS servers for your LAN, you'd likely want this enabled for an ACL that corresponds to the addresses of your DNS servers so they can do DNS server stuff to each other.


Below this, add the following three entries:



```
check-names master ignore;
check-names slave ignore;
check-names response ignore;
```
Select Code
The [check-names directive](https://web.mit.edu/darwin/src/modules/bind/bind/doc/html/options.html#NameChecking) tells bind how to respond when its lookups return results that might clash with RFC standards—most often, this happens when a hostname has an underscore in it. Although [IETF RFC 2181](https://datatracker.ietf.org/doc/html/rfc2181) is the current source of standardization for this kind of stuff, the question of what makes a valid hostname is more religious debate than anything else, and setting those three `check-names` options forces bind to shut up and deal with whatever hostname format we choose to use in every possible lookup context.


Finally, add this:



```
notify no;
```
Select Code
The `notify` directive generates notifications between DNS servers when zone files are modified (among other things), and since we only have the one server, we can turn this off to keep some unnecessary verbosity off the wire and out of the log files.


The `named.conf.options` file after these modifications should look like this, without the comments:



```
options {
	directory "/var/cache/bind";

	allow-query { internal-net; };
	allow-query-cache { internal-net; };
	allow-recursion { none; };
	allow-transfer { none; };

	check-names master ignore;
	check-names slave ignore;
	check-names response ignore;

	notify no;
};
```
Select Code



## Tags:
***ipv4-adresses***: 192.168.1.0 192.168.1.55 10.10.10.0

### Autogenerated tags:
[[dns]] [[dhcpd]] [[ip]] [[ubuntu]] [[dhcp]] [[linux]] [[lts]] [[dnsbox]] [[hostname]] [[acl]]
