# Google released first quantum-resilient FIDO2 key implementation
## Google has announced the first open-source quantum resilient FIDO2 security key implementation, which uses a unique ECC/Dilithium hybrid signature schema co-created with ETH Zurich.
## Information:

+ Link: https://www.bleepingcomputer.com/news/security/google-released-first-quantum-resilient-fido2-key-implementation/
+ Source: Bleeping Computer
+ Author: Bill Toulas
+ Date published: 16 August 2023, 14:35
+ Date scraped: 16 August 2023, 19:05

## Article:
![Main article image](https://www.bleepstatic.com/content/hl-images/2023/06/16/Google__headpic.jpg)



Google has announced the first open-source quantum resilient FIDO2 security key implementation, which uses a unique ECC/Dilithium hybrid signature schema co-created with ETH Zurich.


FIDO2 is the second major version of the Fast IDentity Online authentication standard, and FIDO2 keys are used for passwordless authentication and as a multi-factor authentication (MFA) element.


Google explains that a quantum-resistant FIDO2 security key implementation is a crucial step towards ensuring safety and security as the advent of quantum computing approaches and developments in the field follow an accelerating trajectory.


"As progress toward practical quantum computers is accelerating, preparing for their advent is becoming a more pressing issue as time passes," [explains Google](https://security.googleblog.com/2023/08/toward-quantum-resilient-security-keys.html).


"In particular, standard public key cryptography, which was designed to protect against traditional computers, will not be able to withstand quantum attacks."


With quantum computers being actively developed, there is concern that they will soon be used to more efficiently and quickly crack encryption keys, making encrypted information accessible to governments, threat actors, and researchers.


To protect against quantum computers, a new hybrid algorithm was created by combining the established ECDSA algorithm with the Dilithium algorithm.


[Dilithium](https://pq-crystals.org/dilithium/index.shtml) is a quantum-resistant cryptographic signature scheme that [NIST included](https://csrc.nist.gov/News/2022/pqc-candidates-to-be-standardized-and-round-4) in its post-quantum cryptography standardization proposals, praising its strong security and excellent performance, making it suitable for use in a wide array of applications.



![Dilithium's balanced performance makes it more suitable against alternatives](https://www.bleepstatic.com/images/news/u/1220909/2023/Malware/52/Dilithium.jpg)**Comparison of performance and size of quantum-resistant schemes**  
*(eprint.iacr.org)*


This hybrid signature approach that blends classic and quantum-resistant features wasn't simple to manifest, Google says. Designing a Dilithium implementation that's compact enough for security keys was incredibly challenging.


Its engineers, however, managed to develop a Rust-based implementation that only needs 20KB of memory, making the endeavor practically possible, while they also noted its high-performance potential.


![Diagram](https://www.bleepstatic.com/images/news/u/1220909/2023/Malware/52/diagram.jpg)


The hybrid signature schema was first presented in [a 2022 paper](https://eprint.iacr.org/2022/1225.pdf) and recently [gained recognition](https://sulab-sever.u-aizu.ac.jp/ACNS2023/awards.html) at the ACNS (Applied Cryptography and Network Security) 2023, where it won the "best workshop paper" award.


This [new hybrid implementation](https://github.com/google/OpenSK/releases/tag/hybrid-pqc) is now part of the [OpenSK](https://github.com/google/OpenSK), Google's open-source security keys implementation that supports the FIDO U2F and FIDO2 standards.


The tech giant hopes that its proposal will be adopted by FIDO2 as a new standard and supported by major web browsers with large user bases.


The firm calls the application of next-gen cryptography at the internet scale "a massive undertaking" and urges all stakeholders to move quickly to maintain good progress on that front.


Last week, [Google introduced](https://blog.chromium.org/2023/08/protecting-chrome-traffic-with-hybrid.html) a quantum-resistant hybrid cryptography mechanism called X25519Kyber768 in Chrome 116, which encrypts TLS connections.


This move came in anticipation of the risk of future quantum computers having the capacity to decrypt today's data, addressing the "Harvest Now, Decrypt Later" threat.





## Tags:


### Autogenerated tags:
[[google]] [[fido2]] [[quantum-resistant]] [[dilithium]]
