# APT41: The threat of KeyPlug against Italian industries
## Tinexta Cyber’s Zlab Malware Team uncovered a backdoor known as KeyPlug, which hit for months a variety of Italian industries
## Information:

+ Link: https://securityaffairs.com/163598/apt/apt41-keyplug-targets-italian-industries.html
+ Source: Security Affairs
+ Author: Pierluigi Paganini
+ Date published: 23 May 2024, 13:09
+ Date scraped: 23 May 2024, 15:08

## Article:
![Main article image](https://securityaffairs.com/wp-content/uploads/2024/05/image-22.png)



During an extensive investigation, Tinexta Cyber’s Zlab Malware Team [**uncovered a backdoor known as KeyPlug**](https://yoroi.company/en/research/uncovering-an-undetected-keyplug-implant-attacking-industries-in-italy/), which hit for months a variety of Italian industries. This backdoor is attributed to the arsenal of APT41,a group whose origin is tied to China.


APT41, known also as Amoeba, BARIUM, BRONZE ATLAS, BRONZE EXPORT, Blackfly, Brass Typhoon, Earth Baku, G0044, G0096, Grayfly, HOODOO, LEAD, Red Kelpie, TA415, [WICKED PANDA](https://securityaffairs.com/113458/apt/winnti-attacks-russia-hk.html) e WICKED SPIDER originated from China (with possible ties to the government), it’s known for its complex campaigns and variety of targeted sectors, their motivation varies from exfiltration of sensible data to financial gain.


The backdoor has been developed to target both Windows and Linux operative systems and using different protocols to communicate which depend on the configuration of the malware sample itself.


Tinexta Cyber’s team has analyzed both variants for Windows and Linux, showing common elements that makes the threat capable of remaining resilient inside attacked systems, nonetheless, implants of perimetral defense were present, such as Firewalls, NIDS and EDR employed on every endpoint.


The first malware sample is an implant attacking the Microsoft Windows operating systems. The infection doesn’t directly start from the implant itself but from another component working as a loader written in the .NET framework. This loader is designed to decrypt another file simulating an icon type file. The decryption is through **AES**, a well-known symmetric encryption algorithm, with keys stored directly in the sample itself.


Once all decryption operations are completed, the new payload, with SHA256 hash 399bf858d435e26b1487fe5554ff10d85191d81c7ac004d4d9e268c9e042f7bf, can be analyzed. Delving deeper into that malware sample, it is possible to detect a direct correspondence with malware structure with Mandiant’s report “[Does This Look Infected? A Summary of APT41 Targeting U.S. State Governments](https://www.mandiant.com/resources/blog/apt41-us-state-governments)”. In this specific case, the XOR key is 0x59.


The Linux version of the Keyplug malware, however, is slightly more complex and appears to use VMProtect. During static analysis, many strings related to the UPX packer were detected, but the automatic decompression routine did not work. This variant is designed to decode the payload code during execution, and once this is complete, it relaunches using the syscall fork. This method interrupts the analyst’s control flow, making malware analysis more difficult.


[![Keyplug APT41](https://i0.wp.com/securityaffairs.com/wp-content/uploads/2024/05/image-22.png?resize=1024%2C574&ssl=1)](https://i0.wp.com/securityaffairs.com/wp-content/uploads/2024/05/image-22.png?ssl=1)



Pivoting cyber intelligence information in the cybersecurity community, a potential link has emerged between the APT41 group and the Chinese company I-Soon. On Feb. 16, a large amount of sensitive data from China’s Ministry of Public Security was exposed and then spread on GitHub and Twitter, generating great excitement in the cybersecurity community.


In addition, Hector is a possible RAT (Remote Administration Tool) if not KeyPlug itself, among the arsenal of APT41 uncovered through the [I-SOON](https://securityaffairs.com/159595/hacking/i-soon-chinese-firm-data-leak.html) leak, according to which it can be employed on both Windows and Linux, and uses the WSS protocol.  WSS (WebSocket Secure) is a network protocol used to establish a secure WebSocket connection between a client and a server. It is the encrypted version of the WS (WebSocket) protocol and relies on TLS (Transport Layer Security) to provide security, similar to how HTTPS is the secure version of HTTP. However, this type of protocol is not widely adopted by attackers for malware threats, making, therefore, the attribution narrow toward this type of threat.


A connection between the APT41 group and the ISOON data leak incident can be hypothesized. The advanced techniques used and the wide range of sectors targeted coincide with APT41’s typical modus operandi, suggesting a possible connection to this cyber espionage campaign. Deepening the investigation of the ISOON data leak, especially about the tools and methodologies employed, could offer further insight into the involvement of APT41 or similar groups.


*“APT41, has always been distinguished by its sophistication and ability to conduct global cyber espionage operations. One of the tools it has used and continues to use is KEYPLUG, a modular backdoor capable of evading major detection systems has offered the attacker the ability to be silent within compromised systems for months.” Luigi Martire, Technical Leader at Tinexta Cyber told Security Affairs.  
The risks associated with industrial espionage carried out by groups such as APT41 are significant. Their operations can aim to steal intellectual property, trade secrets, and sensitive information that could confer illicit competitive advantages. Companies operating in technologically advanced or strategic industries are particularly vulnerable, and the consequences of such attacks can include large economic losses, reputational damage, and compromised national security”*


Technical details about the attacks and indicators of compromise (Ioc) are included in [**the report published by Tinexta Cyber**](https://yoroi.company/en/research/uncovering-an-undetected-keyplug-implant-attacking-industries-in-italy/).


[**Pierluigi Paganini**](http://www.linkedin.com/pub/pierluigi-paganini/b/742/559)


Follow me on Twitter: [**@securityaffairs**](https://twitter.com/securityaffairs) and [**Facebook**](https://www.facebook.com/sec.affairs) and [Mastodon](https://infosec.exchange/@securityaffairs)


**(**[**SecurityAffairs**](http://securityaffairs.co/wordpress/)**–** **hacking, APT41)**





---




---





## Tags:
***SHA256-hash***: 399bf858d435e26b1487fe5554ff10d85191d81c7ac004d4d9e268c9e042f7bf

### Autogenerated tags:
[[apt41]] [[malware]] [[tinexta]] [[keyplug]] [[windows]] [[linux]] [[websocket]]
