# NSA shares guidance on securing voice, video communications
## The National Security Agency (NSA) has shared mitigations and best practices that systems administrators should follow when securing Unified Communications (UC) and Voice and Video over IP (VVoIP) call-processing systems.
## Information:

+ Link: https://www.bleepingcomputer.com/news/security/nsa-shares-guidance-on-securing-voice-video-communications/
+ Source: Bleeping Computer
+ Author: Sergiu Gatlan
+ Date published: 17 June 2021, 14:00
+ Date scraped: 12 December 2023, 11:32

## Article:
![Main article image](https://www.bleepstatic.com/content/hl-images/2021/01/05/NSA.jpg)



The National Security Agency (NSA) has shared mitigations and best practices that systems administrators should follow when securing Unified Communications (UC) and Voice and Video over IP (VVoIP) call-processing systems.


UC and VVoIP are call-processing systems used in enterprise environments for various purposes, from video conferencing to instant messaging and project collaboration.


Since these communication systems are tightly integrated with other IT equipment within enterprise networks, they also inadvertently increase the attack surface by introducing new vulnerabilities and the potential for covert access to an organization's communications.


Improperly secured UC/VVoIP devices are exposed to the same security risks and targeted by threat actors through spyware, viruses, software vulnerabilities, and other malicious means if not adequately secured and configured.


"Malicious actors could penetrate the IP networks to eavesdrop on conversations, impersonate users, commit toll fraud and perpetrate denial of service attacks," as the US intelligence agency [explained](https://www.nsa.gov/News-Features/Feature-Stories/Article-View/Article/2661746/nsa-releases-guidance-on-securing-unified-communications-and-voice-and-video-ov/).


"Compromises can lead to high-definition room audio and/or video being covertly collected and delivered to a malicious actor using the IP infrastructure as a transport mechanism."



![UC VVoIP system](https://www.bleepstatic.com/images/news/u/1109292/2021/UC-VVoIP-system.png)*UC VVoIP system (NSA)*


Admins are advised to take these key measures to minimize the risk of their organization's enterprise network being breached by exploiting UC/VVoIP systems:


* Segment enterprise network using Virtual Local Area Networks (VLANs) to separate voice and video traffic from data traffic
* Use access control lists and routing rules to limit access to devices across VLANs
* Implement layer 2 protections and Address Resolution Protocol (ARP) and IP spoofing defenses
* Protect PSTN gateways and Internet perimeters by authenticating all UC/VVoIP connections
* Always keep software up-to-date to mitigate UC/VVoIP software vulnerabilities
* Authenticate and encrypt signaling and media traffic to prevent impersonation and eavesdropping by malicious actors
* Deploy session border controllers (SBCs) to monitor UC/VVoIP traffic and audit call data records (CDRs) using fraud detection solutions to prevent fraud
* Maintain backups of software configurations and installations to ensure availability
* Manage denial of service attacks using rate-limiting and limit the number of incoming calls to prevent UC/VVoIP server overloading
* Use identification cards, biometrics, or other electronic means to control physical access to secure areas with network and UC/VVoIP infrastructure
* Verify features and configurations for new (and potentially rogue) devices in a testbed before adding them to the network

"Taking advantage of the benefits of a UC/VVoIP system, such as cost savings in operations or advanced call processing, comes with the potential for additional risk," the NSA [concluded](https://media.defense.gov/2021/Jun/17/2002744049/-1/-1/1/CSI_DEPLOYING%20SECURE%20VVOIP%20SYSTEMS.PDF).


"A UC/VVoIP system introduces new potential security vulnerabilities. Understand the types of vulnerabilities and mitigations to better secure your UC/VVoIP deployment."


Much more extensive security best practices and mitigations on how to prepare networks, establish network perimeters, use enterprise session controllers, and add endpoints when deploying UC/VVoIP systems are available in the [Cybersecurity Information Sheet released today by the NSA](http://media.defense.gov/2021/Jan/05/2002560140/-1/-1/0/ELIMINATING_OBSOLETE_TLS_UOO197443-20.PDF).


In January, the NSA also shared guidance on how to detect and [replace outdated Transport Layer Security (TLS) protocol versions](https://www.bleepingcomputer.com/news/security/nsa-shares-guidance-tools-to-mitigate-weak-encryption-protocols/) with up-to-date and secure variants.


The agency also warned companies to [use self-hosted DNS-over-HTTPS (DoH) resolvers](https://www.bleepingcomputer.com/news/security/nsa-advises-companies-to-avoid-third-party-dns-resolvers/) to block threat actors' DNS traffic eavesdropping and manipulation attempts.





## Tags:


### Autogenerated tags:
[[uc/vvoip]] [[nsa]] [[ip]] [[mitigations]] [[vvoip]]
