# OpenSSL cert parsing bug causes infinite denial of service loop
## OpenSSL has released a security update to address a vulnerability in the library that, if exploited, activates an infinite loop function and leads to denial of service conditions.
## Information:

+ Link: https://www.bleepingcomputer.com/news/security/openssl-cert-parsing-bug-causes-infinite-denial-of-service-loop/
+ Source: Bleeping Computer
+ Author: Bill Toulas
+ Date published: 16 March 2022, 14:00
+ Date scraped: 16 March 2022, 14:00

## Article:
![Main article image](https://www.bleepstatic.com/content/hl-images/2022/03/16/OpenSSL3.jpg)



OpenSSL has released a security update to address a vulnerability in the library that, if exploited, activates an infinite loop function and leads to denial of service conditions.


Denial of service attacks may not be the most disastrous security problem. However, it can still cause significant business interruption, long-term financial repercussions, and brand reputation degradation for those affected.


That is especially the case for software like OpenSSL, a ubiquitous secure communication library used by many large online platforms. Therefore, any vulnerability that affects the library can significantly impact a [large number of users](https://www.bleepingcomputer.com/news/security/qnap-works-on-patches-for-openssl-bugs-impacting-its-nas-devices/).


## Certificates causing DoS


In this case, the high-severity OpenSLL problem lies in a bug on the BN\_mod\_sqrt() function, that if served a maliciously crafted certificate to parse, it will enter an infinite loop.


The certificate has to contain elliptic curve public keys in compressed form or elliptic curve parameters with a base point encoded in compressed form to trigger the flaw.


“Since certificate parsing happens prior to verification of the certificate signature, any process that parses an externally supplied certificate may thus be subject to a denial of service attack,” describes OpenSSL’s [security notice](https://www.openssl.org/news/secadv/20220315.txt).


“The infinite loop can also be reached when parsing crafted private keys as they can contain explicit elliptic curve parameters.” 


Unfortunately, the problem impacts quite a few deployment scenarios, such as: 


* TLS clients consuming server certificates
* TLS servers consuming client certificates
* Hosting providers taking certificates or private keys from customers
* Certificate authorities parsing certification requests from subscribers
* Anything else which parses ASN.1 elliptic curve parameters

The vulnerability is tracked as [CVE-2022-0778](https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2022-0778), and affects OpenSSL versions 1.0.2 to 1.0.2zc, 1.1.1 to 1.1.1n, and 3.0 to 3.0.1. 


Google’s security researcher Tavis Ormandy discovered the certificate parsing vulnerability and reported his findings to the OpenSSL team on February 24, 2022.



The fixed versions released yesterday are 1.1.1n and 3.0.2, while only premium users of 1.0.2 will be offered a fix through 1.0.2zd.


Because version 1.0.2 does not parse the public key during the parsing of the certificate, the infinite loop is slightly more complicated to trigger than the other versions, but it’s still doable.


OpenSSL 1.0.2 has reached EOL and is not actively supported, so non-premium users are advised to upgrade to a new release branch as soon as possible.


## Already exploited by threat actors?


Although OpenSSL has not said that the bug is already used by threat actors, Italy’s national cybersecurity agency, CSIRT, has marked it as [actively exploited in the wild](https://csirt.gov.it/contenuti/rilevata-vulnerabilita-in-openssl-al02-220316-csirt-ita).


Bleeping Computer has contacted the OpenSSL team to request a clarification on this point, and they told us they are not aware of any active exploitation at this time.


Even if the message is mixed on that front, the low complexity of exploitation and the published information will allow threat actors to test and play quickly with the vulnerability in the future.


An OpenSSL spokesperson shared the following statement with Bleeping Computer:



> 
> The flaw is not too difficult to exploit, but the impact is limited to DoS. The most common scenario where exploitation of this flaw would be a problem would be for a TLS client accessing a malicious server that serves up a problematic certificate. TLS servers may be affected if they are using client authentication (which is a less common configuration) and a malicious client attempts to connect to it. It is difficult to guess to what extent this will translate to active exploitation.
> 
> 
> 


Because most users obtain OpenSSL from a third party, there’s no centralized authority to count upgrade stats, so it’s impossible to estimate how many vulnerable deployments are out there.





## Tags:
***CVE's***: CVE-2022-0778

### Autogenerated tags:
[[openssl]] [[tls]]
