# New Infinite Loop Bug in OpenSSL Could Let Attackers Crash Remote Servers
## A new infinite loop vulnerability (CVE-2022-0778) in OpenSSL could allow attackers to crash remote servers by passing a malformed certificate.
## Information:

+ Link: https://thehackernews.com/2022/03/new-infinite-loop-bug-in-openssl-could.html
+ Source: The Hacker News
+ Author: Ravie Lakshmanan
+ Date published: 16 March 2022, 13:52
+ Date scraped: 16 March 2022, 14:00

## Article:
![Main article image](https://thehackernews.com/new-images/img/a/AVvXsEiia6GKzOpxC2OIf4J2x5AL13hoVD4Cgqwnbz9f8h-peVMn3vCaDuigtlUZT7QcIzj4ZCezLICQflKaMPeF-ojMRzlRX58P4X2Gfy_D-n2M9UECa_zw_UmL0YlnNxOZdOer49IrZblFZvaf_LACRh6yZgDYxilepD6r6P3HnDmrBZq-XTuC40dsVxOS=s728-e1000)


The maintainers of OpenSSL have [shipped patches](https://www.openssl.org/news/vulnerabilities.html) to resolve a high-severity security flaw in its software library that could lead to a denial-of-service (DoS) condition when parsing certificates.


Tracked as [CVE-2022-0778](https://www.openssl.org/news/secadv/20220315.txt) (CVSS score: 7.5), the issue stems from parsing a malformed certificate with invalid explicit [elliptic-curve](https://en.wikipedia.org/wiki/Elliptic-curve_cryptography) parameters, resulting in what's called an "infinite loop." The flaw resides in a function called BN\_mod\_sqrt() that's used to compute the modular square root.


"Since certificate parsing happens prior to verification of the certificate signature, any process that parses an externally supplied certificate may thus be subject to a denial-of-service attack," OpenSSL said in an advisory published on March 15, 2022.


"The infinite loop can also be reached when parsing crafted private keys as they can contain explicit elliptic-curve parameters."


While there is no evidence that the vulnerability has been exploited in the wild, there are a few scenarios where it could be weaponized, including when TLS clients (or servers) access a rogue certificate from a malicious server (or client), or when certificate authorities parse certification requests from subscribers.


The vulnerability impacts OpenSSL versions 1.0.2, 1.1.1, and 3.0, the project owners addressed the flaw with the release of versions 1.0.2zd (for premium support customers), 1.1.1n, and 3.0.2. OpenSSL 1.1.0, while also affected, will not receive a fix as it has reached end-of-life.


Credited with reporting the flaw on February 24, 2022 is Google Project Zero security researcher Tavis Ormandy. The fix was developed by David Benjamin from Google and Tomáš Mráz from OpenSSL.


CVE-2022-0778 is also the second OpenSSL vulnerability resolved since the start of the year. On January 28, 2022, the maintainers fixed a moderate-severity flaw ([CVE-2021-4160](https://www.openssl.org/news/secadv/20220128.txt), CVSS score: 5.9) affecting the library's MIPS32 and MIPS64 squaring procedure.


  





## Tags:
***CVE's***: CVE-2022-0778 CVE-2021-4160

### Autogenerated tags:
[[openssl]]
