# Researcher Releases PoC for Recent Java Cryptographic Vulnerability
## A researcher has published a proof-of-concept exploit for the recently disclosed ECDSA signature validation vulnerability in Java.
## Information:

+ Link: https://thehackernews.com/2022/04/researcher-releases-poc-for-recent-java.html
+ Source: The Hacker News
+ Author: Ravie Lakshmanan
+ Date published: 22 April 2022, 11:43
+ Date scraped: 22 April 2022, 12:00

## Article:
![Main article image](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEi-DujFw32Sf-Wb7JXba4C7UqWLSqTH3JOmu8zI8akYznG0OhFgWlkxvUDJytka6OUbcW77iElusjcSbUvmR-SBmWEgGQkCYo0ChVhkCaRWlzAxy68v9rNlc6LLulVYm0O7-q4sHbwqXRcq4x4Ma8AeqmV1cVjVcdrojLeONsDWCUHQxsEy7uOOF-Ln/s728-e100/java.jpg)


A proof-of-concept (PoC) code demonstrating a newly disclosed digital signature bypass vulnerability in Java has been shared online. 


The [high-severity flaw](https://openjdk.java.net/groups/vulnerability/advisories/2022-04-19) in question, [CVE-2022-21449](https://nvd.nist.gov/vuln/detail/CVE-2022-21449) (CVSS score: 7.5), impacts the following version of Java SE and Oracle GraalVM Enterprise Edition -


* Oracle Java SE: 7u331, 8u321, 11.0.14, 17.0.2, 18
* Oracle GraalVM Enterprise Edition: 20.3.5, 21.3.1, 22.0.0.2


The issue resides in Java's implementation of the Elliptic Curve Digital Signature Algorithm ([ECDSA](https://en.wikipedia.org/wiki/Elliptic_Curve_Digital_Signature_Algorithm)), a [cryptographic mechanism](https://blog.cloudflare.com/ecdsa-the-digital-signature-algorithm-of-a-better-internet/) to [digitally sign](https://en.wikipedia.org/wiki/Digital_signature) messages and data for verifying the authenticity and the integrity of the contents.


In a nutshell, the cryptographic blunder — dubbed Psychic Signatures in Java — makes it possible to present a totally blank signature, which would still be perceived as valid by the vulnerable implementation.


[![](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEh-Oyj4orhNCRTOVLBEVYg-6R2r6GvKNEOrBKbX8iherC7F890sTrAwoline5x77RbEUCRQDZ45zxknXoxmGnvrWPoj5TeNxe5-YD3BSSgkHDCSj4G-T0rwaT0pGudYvqyZurVPvUwhtNOJ4Kkj394d2B9UaOPCR3IHMci4HwznntATh9qQksiq2_Sn/s728-e100/demo.gif)](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEh-Oyj4orhNCRTOVLBEVYg-6R2r6GvKNEOrBKbX8iherC7F890sTrAwoline5x77RbEUCRQDZ45zxknXoxmGnvrWPoj5TeNxe5-YD3BSSgkHDCSj4G-T0rwaT0pGudYvqyZurVPvUwhtNOJ4Kkj394d2B9UaOPCR3IHMci4HwznntATh9qQksiq2_Sn/s728-e100/demo.gif)
Successful exploitation of the flaw could permit an attacker to forge signatures and bypass authentication measures put in place.


The PoC, published by security researcher, Khaled Nassar [involves](https://github.com/khalednassar/CVE-2022-21449-TLS-PoC) a vulnerable client and a malicious TLS server, the former of which accepts an invalid signature from the server, effectively allowing the [TLS handshake](https://www.cloudflare.com/learning/ssl/what-happens-in-a-tls-handshake/) to continue unimpeded.


"It's hard to overstate the severity of this bug," ForgeRock researcher Neil Madden, who discovered and reported the flaw on November 11, 2021, [said](https://neilmadden.blog/2022/04/19/psychic-signatures-in-java/).


"If you are using ECDSA signatures for any of these security mechanisms, then an attacker can trivially and completely bypass them if your server is running any Java 15, 16, 17, or 18 version."


The issue has since been addressed by Oracle as part of its quarterly April 2022 Critical Patch Update (CPU) [released](https://www.oracle.com/security-alerts/cpuapr2022.html) on April 19, 2022.


In light of the release of the PoC, organizations that use Java 15, Java 16, Java 17, or Java 18 in their environments are recommended to prioritize the patches to mitigate active exploitation.


  





## Tags:
***CVE's***: CVE-2022-21449
***ipv4-adresses***: 22.0.0.2

### Autogenerated tags:
[[poc]]
