# QNAP Customers Adrift, Waiting on Fix for OpenSSL Bug
## QNAP is warning clients that a recently disclosed vulnerability affects most of its NAS devices, with no mitigation available while the vendor readies a patch.
## Information:

+ Link: https://kasperskycontenthub.com/threatpost-global/?p=179197
+ Source: ThreatPost
+ Author: Elizabeth Montalbano
+ Date published: 31 March 2022, 13:22
+ Date scraped: 31 March 2022, 14:02

## Article:
![Main article image](https://media.threatpost.com/wp-content/uploads/sites/103/2022/03/31091436/Adrift-at-sea-scaled-e1648732490242.jpeg)


Customers of Taiwan-based [QNAP Systems](https://www.qnap.com/pt-pt) are in a bit of limbo, waiting until the company releases a patch for an OpenSSL bug that the company has [warned](https://www.qnap.com/en/security-advisory/QSA-22-06) affects most of its network-attached storage (NAS) devices. The vulnerability can trigger an infinite loop that creates a denial-of-service (DoS) scenario.


Though the bug – tracked as [CVE-2022-0778](https://nvd.nist.gov/vuln/detail/CVE-2022-0778) and rated 7.5 (high severity) on the CVSS severity-rating scale – [has been patched](https://www.openssl.org/news/secadv/20220315.txt) by OpenSSL, QNAP hasn’t gotten around to applying a fix yet for its NAS devices affected by the vulnerability. The company is telling customers that “there is no mitigation available” and they “must check back and install security updates as soon as they become available.”


“QNAP is thoroughly investigating the case,” the company said. “We will release security updates and provide further information as soon as possible.”


[![Infosec Insiders Newsletter](https://media.threatpost.com/wp-content/uploads/sites/103/2021/07/10165815/infosec_insiders_in_article_promo.png)](https://threatpost.com/infosec-insider-subscription-page/?utm_source=ART&utm_medium=ART&utm_campaign=InfosecInsiders_Newsletter_Promo/)


The vulnerability is in OpenSSL’s BN\_mod\_sqrt() function, which computes a modular square root. The bug can be triggered by crafting a certificate that has invalid explicit curve parameters, causing the function to loop forever, according to [its listing](https://nvd.nist.gov/vuln/detail/CVE-2022-0778) in the NIST National Vulnerability Database. This creates DoS conditions on the device, according to OpenSSL. OpenSSL is a popular cryptography library primarily used by networking software that offers open-source application of the TLS protocol.


“Since certificate parsing happens prior to verification of the certificate signature, any process that parses an externally supplied certificate may thus be subject to a denial of service attack,” according to the listing. “The infinite loop can also be reached when parsing crafted private keys as they can contain explicit elliptic curve parameters.”


Vulnerable scenarios on devices using OpenSSL include:


* TLS clients consuming server certificates,
* TLS servers consuming client certificates,
* Hosting providers taking certificates or private keys from customers,
* Certificate authorities parsing certification requests from subscribers, or
* Anything else that parses ASN.1 elliptic curve parameters.


QNAP devices affected by the bug are:


* QTS 5.0.x and later
* QTS 4.5.4 and later
* QTS 4.3.6 and later
* QTS 4.3.4 and later
* QTS 4.3.3 and later
* QTS 4.2.6 and later
* QuTS hero h5.0.x and later
* QuTS hero h4.5.4 and later
* QuTScloud c5.0.x


Though QNAP said it’s not aware of any exploits for the bug, [a security advisory](https://www.csirt.gov.it/contenuti/rilevata-vulnerabilita-in-openssl-al02-220316-csirt-ita) issued by Italy’s national cybersecurity agency, CSIRT, suggests that it already is being exploited in the wild.


## **QNAP Under Fire**


QNAP devices have indeed had their share of cybersecurity woes in the past several months, a number of which are ongoing.


As the company readies a fix for the OpenSSL flaw, it’s also working on another patch for the so-called [Dirty Pipe Linux kernel flaw](https://blog.malwarebytes.com/exploits-and-vulnerabilities/2022/03/linux-dirty-pipe-vulnerability-gives-unprivileged-users-root-access/) discovered earlier this month, which also currently has no mitigation on QNAP NAS devices. The flaw, a local privilege-escalation vulnerability, affects the Linux kernel on [QNAP NAS running QTS 5.0.x and QuTS hero h5.0.x](https://threatpost.com/most-qnap-nas-devices-affected-by-dirty-pipe-linux-flaw/178920/).


Attackers also have been pummeling QNAP devices with both ransomware and brute-force attacks since the beginning of the year, the [latter of which](https://threatpost.com/qnap-nas-devices-ransomware-attacks/177452/) prompted the vendor to urge customers to get their internet-exposed NAS devices off the internet.


In late January, QNAP forced out an unexpected and not entirely welcome update to its customers’ NAS devices after [warning them](https://www.qnap.com/en/security-news/2022/take-immediate-actions-to-stop-your-nas-from-exposing-to-the-internet-and-fight-against-ransomware-together) that [the DeadBolt ransomware](https://threatpost.com/conti-deadbolt-delta-qnap-ransomware/178083/) was mounting an offensive against them. And just last week, reports surfaced that [DeadBolt was at it](https://threatpost.com/deadbolt-ransomware-qnap-again/179057/) again in a new wave of attacks against QNAP.


The current OpenSSL scenario also is not the first time the vendor’s devices were rattled by a flaw in the cryptography library. Last August, [two vulnerabilities](https://threatpost.com/qnap-openssl-bugs/169054/) tracked as [CVE-2021-3711](https://www.qnap.com/en-us/security-advisory/QSA-21-39) and [CVE-2021-3712](https://www.qnap.com/en-us/security-advisory/QSA-21-40) that respectively could cause remote-code execution (RCE) and DoS also prompted a security advisory and eventually emergency patches by QNAP.


***Moving to the cloud? Discover emerging cloud-security threats along with solid advice for how to defend your assets with our*** [***FREE downloadable eBook***](https://bit.ly/3Jy6Bfs)***, “Cloud Security: The Forecast for 2022.”*** ***We explore organizations’ top risks and challenges, best practices for defense, and advice for security success in such a dynamic computing environment, including handy checklists.***





## Tags:
***CVE's***: CVE-2021-3711 CVE-2022-0778 CVE-2021-3712

### Autogenerated tags:
[[qnap]] [[openssl]] [[nas]] [[tls]] [[quts]]
