# Attacks on 5G Infrastructure From Users’ Devices
## Crafted packets from cellular devices such as mobile phones can exploit faulty state machines in the 5G core to attack cellular infrastructure. Smart devices that critical industries such as defense, utilities, and the medical sectors use for their daily operations depend on the speed, efficiency, and productivity brought by 5G. This entry describes CVE-2021-45462 as a potential use case to deploy a denial-of-service (DoS) attack to private 5G networks.
## Information:

+ Link: https://www.trendmicro.com/en_us/research/23/i/attacks-on-5g-infrastructure-from-users-devices.html
+ Source: Trend Micro
+ Author: Salim S.I.
+ Date published: 20 September 2023, 00:00
+ Date scraped: 20 September 2023, 08:00

## Article:
![Main article image](https://www.trendmicro.com/content/dam/trendmicro/global/en/research/thumbnails/attacks-on-5g-infrastructure-from-users-devices-critical-industries.jpg)






5G unlocks [unprecedented applications](https://www.trendmicro.com/en_us/ciso/22/i/pros-cons-5g.html) previously unreachable with conventional wireless connectivity to help enterprises accelerate digital transformation, reduce operational costs, and maximize productivity for the best return on investments. To achieve its goals, 5G relies on key service categories: massive machine-type communications (mMTC), enhanced mobile broadband (eMBB), and ultra-reliable low-latency communication (uRLLC).


With the growing spectrum for commercial use, usage and popularization of private 5G networks are on the rise. The manufacturing, defense, ports, energy, logistics, and mining industries are just some of the earliest adopters of these private networks, especially for companies rapidly leaning on the internet of things (IoT) for digitizing production systems and supply chains. Unlike public grids, the cellular infrastructure equipment in private 5G might be owned and operated by the user-enterprise themselves, system integrators, or by carriers. However, given the growing study and exploration of the use of 5G for the development of various technologies, cybercriminals are also looking into [exploiting](https://www.trendmicro.com/vinfo/tmr/?/us/security/news/internet-of-things/plague-private-5g-networks) the [threats](https://www.trendmicro.com/en_us/research/22/g/private-5g-network-security-part-1.html) and [risks](https://www.trendmicro.com/en_us/research/23/h/private-5g-network-security.html) that can be used to intrude into the systems and networks of both users and organizations via this new communication standard. This entry explores how normal user devices can be abused in relation to 5G’s network infrastructure and use cases.


5G topology


In an end-to-end 5G cellular system, user equipment (aka UE, such as mobile phones and internet-of-things [IoT] devices), connect to a base station via radio waves. The base station is connected to the 5G core through a wired IP network.


Functionally, the 5G core can be split into two: the control plane and the user plane. In the network, the control plane carries the signals and facilitates the traffic based on how it is exchanged from one endpoint to another. Meanwhile, the user plane functions to connect and process the user data that comes over the radio area network (RAN).


The base station sends control signals related to device attachment and establishes the connection to the control plane via NGAP (Next-Generation Application Protocol). The user traffic from devices is sent to the user plane using GTP-U (GPRS tunneling protocol user plane). From the user plane, the data traffic is routed to the external network.






![fig1-attacks-on-5g-infrastructure-from-users-devices](https://www.trendmicro.com/content/dam/trendmicro/global/en/research/23/i/attacks-on-5g-infrastructure-from-users-devices/figure1-attacks-on-5G-infrastructure-from-users-devices-critical-industries.jpg)
Figure 1. The basic 5G network infrastructure







The UE subnet and infrastructure network are separate and isolated from each other; user equipment is not allowed to access infrastructure components. This isolation helps protect the 5G core from CT (Cellular Technology) protocol attacks generated from users’ equipment.  




Is there a way to get past this isolation and attack the 5G core? The next sections elaborate on the how cybercriminals could abuse components of the 5G infrastructure, particularly the GTP-U.


GTP-U


GTP-U is a tunneling protocol that exists between the base station and 5G user plane using port 2152. The following is the structure of a user data packet encapsulated in GTP-U.






![fig2-attacks-on-5g-infrastructure-from-users-devices](https://www.trendmicro.com/content/dam/trendmicro/global/en/research/23/i/attacks-on-5g-infrastructure-from-users-devices/figure2-attacks-on-5G-infrastructure-from-users-devices-critical-industries.jpg)
Figure 2. GTP-U data packet






A GTP-U tunnel packet is created by attaching a header to the original data packet. The added header consists of a UDP (User Datagram Protocol) transport header plus a GTP-U specific header. The GTP-U header consists of the following fields:


* Flags: This contains the version and other information (such as an indication of whether optional header fields are present, among others).
* Message type: For GTP-U packet carrying user data, the message type is *0xFF.*
* Length: This is the length in bytes of everything that comes after the Tunnel Endpoint Identifier (TEID) field.
* TEID: Unique value for a tunnel that maps the tunnel to user devices


The GTP-U header is added by the GTP-U nodes (the base station and User Plane Function or UPF). However, the user cannot see the header on the user interface of the device. Therefore, user devices cannot manipulate the header fields.


Although GTP-U is a standard tunneling technique, its use is mostly restricted to CT environments between the base station and the UPF or between UPFs. Assuming the best scenario, the backhaul between the base station and the UPF is encrypted, protected by a firewall, and closed to outside access. Here is a breakdown of the ideal scenario: [GSMA](https://www.gsma.com/) [recommends](https://www.gsma.com/security/wp-content/uploads/2020/02/FS.31-v2.0.pdf) IP security (IPsec) between the base station and the UPF. In such a scenario, packets going to the GTP-U nodes come from authorized devices only. If these devices follow specifications and implement them well, none of them will send anomalous packets. Besides, robust systems are expected to have strong sanity checks to handle received anomalies, especially obvious ones such as invalid lengths, types, and extensions, among others.


In reality, however, the scenario could often be different and would require a different analysis altogether. Operators are reluctant to deploy IPsec on the [N3](https://emblasoft.com/blog/the-importance-of-testing-the-5g-n3-and-4g-s1-u-interfaces#:~:text=The%20importance%20of%20the%205G%20N3%20and%204G%20S1%2DU%20interfaces) interface because it is CPU-intensive and reduces the throughput of user traffic. Also, since the user data is perceived to be protected at the application layer (with additional protocols such as TLS or Transport Layer Security), some consider IP security redundant. One might think that for as long as the base station and packet-core conform to the specific, there will be no anomalies. Besides, one might also think that for all robust systems require sanity checks to catch any obvious anomalies. However, previous studies have shown that many N3 nodes (such as UPF) around the world, although they should not be, are exposed to the internet. This is shown in the following sections.






![fig3-attacks-on-5g-infrastructure-from-users-devices](https://www.trendmicro.com/content/dam/trendmicro/global/en/research/23/i/attacks-on-5g-infrastructure-from-users-devices/figure3-attacks-on-5G-infrastructure-from-users-devices-critical-industries.png)






Figure 3. Exposed UPF interfaces due to misconfigurations or lack of firewalls; screenshot taken from Shodan and used in a [previously published](https://documents.trendmicro.com/assets/white_papers/Outside-Looking-In-How-a-Packet-Reflection-Vulnerability-Could-Allow-Attackers-to-Infiltrate-Internal-5G-Networks.pdf) research


We discuss two concepts that can exploit the GTP-U using CVE-2021-45462. In [Open5GS](https://open5gs.org/), a C-language open-source implementation for 5G Core and Evolved Packet Core (EPC), sending a zero-length, type=255 GTP-U packet from the user device resulted in a denial of service (DoS) of the UPF. This is [CVE-2021-45462](https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-45462), a security gap in the packet core that can crash the UPF (in 5G) or Serving Gateway User Plane Function (SGW-U in 4G/LTE) via an anomalous GTP-U packet crafted from the UE and by sending this anomalous GTP-U packet in the GTP-U. Given that the exploit affects a critical component of the infrastructure and cannot be resolved as easily, the vulnerability has received a Medium to High severity rating.


**GTP-U nodes: Base station and UPF**


GTP-U nodes are endpoints that encapsulate and decapsulate GTP-U packets. The base station is the GTP-U node on the user device side. As the base station receives user data from the UE, it converts the data to IP packets and encapsulates it in the GTP-U tunnel.


The UPF is the GTP-U node on the 5G core (5GC) side. When it receives a GTP-U packet from the base station, the UPF decapsulates the outer GTP-U header and takes out the inner packet. The UPF looks up the destination IP address in a routing table (also maintained by the UPF) without checking the content of the inner packet, after which the packet is sent on its way.


**GTP-U in GTP-U**


What if a user device crafts an anomalous GTP-U packet and sends it to a packet core?






![fig4-attacks-on-5g-infrastructure-from-users-devices](https://www.trendmicro.com/content/dam/trendmicro/global/en/research/23/i/attacks-on-5g-infrastructure-from-users-devices/figure4-attacks-on-5G-infrastructure-from-users-devices-critical-industries.png)
Figure 4. A specially crafted anomalous GTP-U packet






![fig5-attacks-on-5g-infrastructure-from-users-devices](https://www.trendmicro.com/content/dam/trendmicro/global/en/research/23/i/attacks-on-5g-infrastructure-from-users-devices/figure5-attacks-on-5G-infrastructure-from-users-devices-critical-industries.jpg)
Figure 5. Sending an anomalous GTP-U packet from the user device






As intended, the base station will tunnel this packet inside its GTP-U tunnel and send to the UPF. This results in a GTP-U in the GTP-U packet arriving at the UPF. There are now two GTP-U packets in the UPF: The outer GTP-U packet header is created by the base station to encapsulate the data packet from the user device. This outer GTP-U packet has *0xFF* as its message type and a length of 44. This header is normal. The inner GTP-U header is crafted and sent by the user device as a data packet. Like the outer one, this inner GTP-U has *0xFF* as message type, but a length of 0 is not normal.


The source IP address of the inner packet belongs to the user device, while the source IP address of the outer packet belongs to the base station. Both inner and outer packets have the same destination IP address: that of the UPF.


The UPF decapsulates the outer GTP-U and passes the functional checks. The inner GTP-U packet’s destination is again the same UPF. What happens next is implementation-specific:


* Some implementations maintain a state machine for packet traversal. Improper implementation of the state machine might result in processing this inner GTP-U packet. This packet might have passed the checks phase already since it shares the same packet-context with the outer packet. This leads to having an anomalous packet inside the system, past sanity checks.
* Since the inner packet’s destination is the IP address of UPF itself, the packet might get sent to the UPF. In this case, the packet is likely to hit the functional checks and therefore becomes less problematic than the previous case.


Attack vector


Some 5G core vendors leverage Open5GS code. For example, [NextEPC](https://nextepc.com/) (4G system, rebranded as Open5GS in 2019 to add 5G, with remaining products from the old brand) has an enterprise offer for LTE/5G, which draws from Open5GS’ code. No attacks or indications of threats in the wild have been observed, but our tests indicate potential risks using the identified scenarios.


The importance of the attack is in the attack vector: the cellular infrastructure attacks from the UE. The exploit only requires a mobile phone (or a computer connected via a cellular dongle) and a few lines of Python code to abuse the opening and mount this class of attack. The GTP-U in GTP-U attacks is a [well-known](https://www.gsma.com/membership/wp-content/uploads/2017/09/Positive-Technologies-White-Paper.pdf) [technique](https://docs.paloaltonetworks.com/service-providers/11-0/mobile-network-infrastructure-getting-started/gtp/gtp-get-pcap-gtp-event), and backhaul IP security and encryption do not prevent this attack. In fact, these security measures might hinder the firewall from inspecting the content.


Remediation and insights


Critical industries such as the medical and utility sectors are just some of the early adopters of private 5G systems, and its breadth and depth of popular use are only expected to grow further. Reliability for continuous, uninterrupted operations is critical for these industries as there are lives and real-world implications at stake. The foundational function of these sectors are the reason that they choose to use a private 5G system over Wi-Fi. It is imperative that private 5G systems offer unfailing connectivity as a successful attack on any 5G infrastructure could bring the entire network down.


In this entry, the abuse of CVE-2021-45462 can result in a DoS attack. The root cause of CVE-2021-45462 (and most GTP-U-in-GTP-U attacks) is the improper error checking and error handling in the packet core. While GTP-U-in-GTP-U itself is harmless, the proper fix for the gap has to come from the packet-core vendor, and infrastructure admins must use the latest versions of the software.


A GTP-U-in-GTP-U attack can also be used to leak sensitive information such as the IP addresses of infrastructure nodes. GTP-U peers should therefore be prepared to handle GTP-U-in-GTP-U packets. In CT environments, they should use an intrusion prevention system (IPS) or firewalls that can understand CT protocols. Since GTP-U is not normal user traffic, especially in private 5G, security teams can prioritize and drop GTP-U-in-GTP-U traffic.


As a general rule, the registration and use of SIM cards must be strictly regulated and managed. An attacker with a stolen SIM card could insert it to an attacker's device to connect to a network for malicious deployments. Moreover, the responsibility of security might be ambiguous to some in a shared operating model, such as end-devices and the edge of the infrastructure chain owned by the enterprise. Meanwhile, the cellular infrastructure is owned by the integrator or carrier. This presents a hard task for security operation centers (SOCs) to bring relevant information together from different domains and solutions.


In addition, due to the downtime and tests required, updating critical infrastructure software regularly to keep up with vendor's patches is not easy, nor will it ever be. Virtual patching with IPS or layered firewalls is thus strongly recommended. Fortunately, GTP-in-GTP is rarely used in real-world applications, so it might be safe to completely block all GTP-in-GTP traffic. We recommend using layered security solutions that combine IT and communications technology (CT) security and visibility. Implementing zero-trust solutions, such as [Trend Micro™ Mobile Network Security](https://www.trendmicro.com/en_us/business/products/iot/mobile-network-security.html), powered by [CTOne](https://www.ctone.com/), adds another security layer for enterprises and critical industries to prevent the unauthorized use of their respective private networks for a continuous and undisrupted industrial ecosystem, and by ensuring that the SIM is used only from an authorized device. Mobile Network Security also brings CT and IT security into a unified visibility and management console.








## Tags:
***CVE's***: CVE-2021-45462

### Autogenerated tags:
[[gtp-u]] [[5g]] [[upf]] [[ip]] [[ue]] [[gtp-u-in-gtp-u]] [[cve-2021-45462]] [[open5gs]] [[0xff]]
